@@ -1,6 +1,14 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -8,6 +16,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <assert.h>
+#include <time.h>
 
 #if defined(_WIN32)
   // None
@@ -102,9 +111,11 @@ int32_t SPVM__Sys__Process__sleep(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Process__usleep(SPVM_ENV* env, SPVM_VALUE* stack) {
   
+  // The usec argument is unsigned int (usually 32-bit), 
+  // but we receive it as int64_t from SPVM to prevent overflow during passing.
   int64_t usec = stack[0].lval;
   
-  int32_t status = usleep(usec);
+  int32_t status = usleep((useconds_t)usec);
   
   if (status == -1) {
     env->die(env, stack, "[System Error]usleep() failed.", __func__, FILE_NAME, __LINE__);
@@ -415,7 +426,7 @@ int32_t SPVM__Sys__Process__execv(SPVM_ENV* env, SPVM_VALUE* stack) {
 
 int32_t SPVM__Sys__Process__WIFEXITED(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-#ifdef WCONTINUED
+#ifdef WIFEXITED
   stack[0].ival = WIFEXITED(stack[0].ival);
   return 0;
 #else
