@@ -1,6 +1,15 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
+
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -14,7 +23,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRALN(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_ADRALN;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_ADRALN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_ADRALN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -26,7 +35,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_ADRERR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_ADRERR;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_ADRERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_ADRERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -38,7 +47,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AO(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = BUS_MCEERR_AO;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_MCEERR_AO is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_MCEERR_AO is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -50,7 +59,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCEERR_AR(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = BUS_MCEERR_AR;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_MCEERR_AR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_MCEERR_AR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -62,7 +71,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_MCERR_(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_MCERR_;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_MCERR_ is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_MCERR_ is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -74,7 +83,7 @@ int32_t SPVM__Sys__Signal__Constant__BUS_OBJERR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = BUS_OBJERR;
   return 0;
 #else
-  env->die_v2(env, stack, "BUS_OBJERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "BUS_OBJERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -86,7 +95,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_CONTINUED(SPVM_ENV* env, SPVM_VALUE* st
   stack[0].ival = CLD_CONTINUED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_CONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_CONTINUED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -98,7 +107,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_DUMPED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_DUMPED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_DUMPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_DUMPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -110,7 +119,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_EXITED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_EXITED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_EXITED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_EXITED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -122,7 +131,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_KILLED(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = CLD_KILLED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_KILLED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_KILLED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -134,7 +143,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_STOPPED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLD_STOPPED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_STOPPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_STOPPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -146,7 +155,7 @@ int32_t SPVM__Sys__Signal__Constant__CLD_TRAPPED(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = CLD_TRAPPED;
   return 0;
 #else
-  env->die_v2(env, stack, "CLD_TRAPPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "CLD_TRAPPED is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -158,7 +167,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTDIV;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTDIV is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTDIV is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -170,7 +179,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTINV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTINV;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTINV is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTINV is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -182,7 +191,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTOVF;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTOVF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTOVF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -194,7 +203,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTRES(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTRES;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTRES is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTRES is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -206,7 +215,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTSUB(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTSUB;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTSUB is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTSUB is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -218,7 +227,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_FLTUND(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_FLTUND;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_FLTUND is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_FLTUND is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -230,7 +239,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTDIV(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_INTDIV;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_INTDIV is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_INTDIV is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -242,7 +251,7 @@ int32_t SPVM__Sys__Signal__Constant__FPE_INTOVF(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FPE_INTOVF;
   return 0;
 #else
-  env->die_v2(env, stack, "FPE_INTOVF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FPE_INTOVF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -254,7 +263,7 @@ int32_t SPVM__Sys__Signal__Constant__FUTEX_WAIT(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = FUTEX_WAIT;
   return 0;
 #else
-  env->die_v2(env, stack, "FUTEX_WAIT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "FUTEX_WAIT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -266,7 +275,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_BADSTK(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_BADSTK;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_BADSTK is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_BADSTK is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -278,7 +287,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_COPROC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_COPROC;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_COPROC is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_COPROC is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -290,7 +299,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLADR(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLADR;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_ILLADR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_ILLADR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -302,7 +311,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLOPC;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_ILLOPC is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_ILLOPC is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -314,7 +323,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLOPN(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLOPN;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_ILLOPN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_ILLOPN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -326,7 +335,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_ILLTRP(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_ILLTRP;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_ILLTRP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_ILLTRP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -338,7 +347,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVOPC(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_PRVOPC;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_PRVOPC is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_PRVOPC is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -350,7 +359,7 @@ int32_t SPVM__Sys__Signal__Constant__ILL_PRVREG(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = ILL_PRVREG;
   return 0;
 #else
-  env->die_v2(env, stack, "ILL_PRVREG is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "ILL_PRVREG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -362,7 +371,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_ERR(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_ERR;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_ERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_ERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -374,7 +383,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_HUP(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_HUP;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_HUP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_HUP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -386,7 +395,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_IN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = POLL_IN;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_IN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_IN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -398,7 +407,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_MSG(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_MSG;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_MSG is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_MSG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -410,7 +419,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_OUT(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_OUT;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_OUT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_OUT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -422,7 +431,7 @@ int32_t SPVM__Sys__Signal__Constant__POLL_PRI(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = POLL_PRI;
   return 0;
 #else
-  env->die_v2(env, stack, "POLL_PRI is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "POLL_PRI is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -434,7 +443,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_SIGIO(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_SIGIO;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_SIGIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_SIGIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -446,7 +455,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_ASYNCIO(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = SI_ASYNCIO;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_ASYNCIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_ASYNCIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -458,7 +467,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_KERNEL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_KERNEL;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_KERNEL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_KERNEL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -470,7 +479,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_MESGQ(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_MESGQ;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_MESGQ is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_MESGQ is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -482,7 +491,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_QUEUE(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_QUEUE;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_QUEUE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_QUEUE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -494,7 +503,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_TIMER(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_TIMER;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_TIMER is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_TIMER is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -506,7 +515,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_TKILL(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SI_TKILL;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_TKILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_TKILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -518,7 +527,7 @@ int32_t SPVM__Sys__Signal__Constant__SI_USER(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SI_USER;
   return 0;
 #else
-  env->die_v2(env, stack, "SI_USER is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SI_USER is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -530,7 +539,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRANCH(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TRAP_BRANCH;
   return 0;
 #else
-  env->die_v2(env, stack, "TRAP_BRANCH is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "TRAP_BRANCH is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -542,7 +551,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_BRKPT(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = TRAP_BRKPT;
   return 0;
 #else
-  env->die_v2(env, stack, "TRAP_BRKPT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "TRAP_BRKPT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -554,7 +563,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_HWBKPT(SPVM_ENV* env, SPVM_VALUE* stac
   stack[0].ival = TRAP_HWBKPT;
   return 0;
 #else
-  env->die_v2(env, stack, "TRAP_HWBKPT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "TRAP_HWBKPT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -566,7 +575,7 @@ int32_t SPVM__Sys__Signal__Constant__TRAP_TRACE(SPVM_ENV* env, SPVM_VALUE* stack
   stack[0].ival = TRAP_TRACE;
   return 0;
 #else
-  env->die_v2(env, stack, "TRAP_TRACE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "TRAP_TRACE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -578,7 +587,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGABRT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGABRT;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGABRT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGABRT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -590,7 +599,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGALRM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGALRM;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGALRM is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGALRM is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -602,7 +611,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGBUS(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGBUS;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGBUS is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGBUS is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -614,7 +623,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGCHLD(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGCHLD;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGCHLD is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGCHLD is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -626,7 +635,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGCONT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGCONT;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGCONT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGCONT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -638,7 +647,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGFPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGFPE;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGFPE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGFPE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -650,7 +659,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGHUP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGHUP;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGHUP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGHUP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -662,7 +671,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGILL;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -674,7 +683,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGINT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGINT;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGINT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGINT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -686,7 +695,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGIO(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGIO;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGIO is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -698,7 +707,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGKILL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGKILL;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGKILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGKILL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -710,7 +719,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPIPE(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPIPE;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGPIPE is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGPIPE is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -722,7 +731,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPROF(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPROF;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGPROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGPROF is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -734,7 +743,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGPWR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGPWR;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGPWR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGPWR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -746,7 +755,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGQUIT(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGQUIT;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGQUIT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGQUIT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -758,7 +767,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMAX(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGRTMAX;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGRTMAX is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGRTMAX is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -770,7 +779,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGRTMIN(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGRTMIN;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGRTMIN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGRTMIN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -782,7 +791,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSEGV(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSEGV;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGSEGV is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGSEGV is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -794,7 +803,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTKFLT(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGSTKFLT;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGSTKFLT is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGSTKFLT is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -806,7 +815,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSTOP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSTOP;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGSTOP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGSTOP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -818,7 +827,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGSYS(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGSYS;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGSYS is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGSYS is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -830,7 +839,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTERM(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTERM;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGTERM is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGTERM is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -842,7 +851,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTRAP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTRAP;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGTRAP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGTRAP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -854,7 +863,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTSTP(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTSTP;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGTSTP is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGTSTP is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -866,7 +875,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTIN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTTIN;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGTTIN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGTTIN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -878,7 +887,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGTTOU(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGTTOU;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGTTOU is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGTTOU is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -890,7 +899,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGURG(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGURG;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGURG is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGURG is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -902,7 +911,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR1(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGUSR1;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGUSR1 is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGUSR1 is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -914,7 +923,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGUSR2(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGUSR2;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGUSR2 is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGUSR2 is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -926,7 +935,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGVTALRM(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGVTALRM;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGVTALRM is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGVTALRM is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -938,7 +947,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGWINCH(SPVM_ENV* env, SPVM_VALUE* stack)
   stack[0].ival = SIGWINCH;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGWINCH is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGWINCH is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -950,7 +959,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGXCPU(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGXCPU;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGXCPU is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGXCPU is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -962,7 +971,7 @@ int32_t SPVM__Sys__Signal__Constant__SIGXFSZ(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = SIGXFSZ;
   return 0;
 #else
-  env->die_v2(env, stack, "SIGXFSZ is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIGXFSZ is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -974,7 +983,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_DFL(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_DFL;
   return 0;
 #else
-  env->die_v2(env, stack, "SIG_DFL is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIG_DFL is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -986,7 +995,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_ERR(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_ERR;
   return 0;
 #else
-  env->die_v2(env, stack, "SIG_ERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIG_ERR is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
@@ -998,7 +1007,7 @@ int32_t SPVM__Sys__Signal__Constant__SIG_IGN(SPVM_ENV* env, SPVM_VALUE* stack) {
   stack[0].ival = (int32_t)(intptr_t)SIG_IGN;
   return 0;
 #else
-  env->die_v2(env, stack, "SIG_IGN is not defined in this system.", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "SIG_IGN is not defined in this system.", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #endif
 
