@@ -1,6 +1,15 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
+
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -19,13 +28,13 @@ int32_t SPVM__Sys__Signal__Handler__eq(SPVM_ENV* env, SPVM_VALUE* stack) {
   void* obj_handler1 = stack[0].oval;
   
   if (!obj_handler1) {
-    return env->die_v2(env, stack, "The handler $handler1 must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The handler $handler1 must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   void* obj_handler2 = stack[1].oval;
   
   if (!obj_handler2) {
-    return env->die_v2(env, stack, "The handler $handler2 must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The handler $handler2 must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   void* handler1 = env->get_pointer(env, stack, obj_handler1);
