@@ -1,6 +1,14 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 #include <assert.h>
@@ -181,7 +189,7 @@ int32_t SPVM__Sys__Socket__Addrinfo__ai_addr(SPVM_ENV* env, SPVM_VALUE* stack) {
         break;
       }
       default : {
-        return env->die_v2(env, stack, "ai_addr->sa_family is an unknown address family.", __func__, FILE_NAME, __LINE__);
+        return env->die(env, stack, "ai_addr->sa_family is an unknown address family.", __func__, FILE_NAME, __LINE__);
       }
     }
     
