@@ -1,6 +1,14 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
@@ -10,7 +18,7 @@ static const char* FILE_NAME = "Sys/Socket/Ip_mreq_source.c";
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#new method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#new method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -29,7 +37,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__new(SPVM_ENV* env, SPVM_VALUE* stack)
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#DESTROY method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#DESTROY method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_multi_request_source = stack[0].oval;
@@ -47,7 +55,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__DESTROY(SPVM_ENV* env, SPVM_VALUE* st
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -72,7 +80,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_multiaddr(SPVM_ENV* env, SPVM_VAL
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_multiaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -90,7 +98,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_multiaddr(SPVM_ENV* env, SPVM
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -115,7 +123,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_interface(SPVM_ENV* env, SPVM_VAL
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_interface method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
@@ -133,7 +141,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_interface(SPVM_ENV* env, SPVM
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t error_id = 0;
@@ -158,7 +166,7 @@ int32_t SPVM__Sys__Socket__Ip_mreq_source__imr_sourceaddr(SPVM_ENV* env, SPVM_VA
 
 int32_t SPVM__Sys__Socket__Ip_mreq_source__set_imr_sourceaddr(SPVM_ENV* env, SPVM_VALUE* stack) {
 #if defined(__OpenBSD__)
-  env->die_v2(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
+  env->die(env, stack, "Sys::Socket::Ip_mreq_source#set_imr_sourceaddr method is not supported in this system(defined(__OpenBSD__)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   void* obj_self = stack[0].oval;
