@@ -1,6 +1,15 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
+
 #include "spvm_native.h"
 #include "spvm_socket_util.h"
 
@@ -132,7 +141,7 @@ int32_t SPVM__Sys__Socket__Sockaddr__In6__set_sin6_addr(SPVM_ENV* env, SPVM_VALU
   void* obj_address = stack[1].oval;
 
   if (!obj_address) {
-    return env->die_v2(env, stack, "The address must be defined.", __func__, FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address must be defined.", __func__, FILE_NAME, __LINE__);
   }
   
   struct in6_addr* address = env->get_pointer(env, stack, obj_address);
