@@ -1,6 +1,14 @@
 // Copyright (c) 2023 Yuki Kimoto
 // MIT License
 
+#ifdef __linux__
+  // Enable X/Open System Interfaces (SUSv4) functions and POSIX.1-2008 standard functions
+  #define _XOPEN_SOURCE 700
+
+  // Enable BSD and System V extensions
+  #define _DEFAULT_SOURCE
+#endif
+
 #include "spvm_native.h"
 
 #include <unistd.h>
@@ -99,6 +107,7 @@ int32_t SPVM__Sys__User__seteuid(SPVM_ENV* env, SPVM_VALUE* stack) {
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t euid = stack[0].ival;
+  
   int32_t status = seteuid(euid);
   
   if (status == -1) {
@@ -139,6 +148,7 @@ int32_t SPVM__Sys__User__setegid(SPVM_ENV* env, SPVM_VALUE* stack) {
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
   int32_t egid = stack[0].ival;
+  
   int32_t status = setegid(egid);
 
   if (status == -1) {
@@ -171,6 +181,7 @@ int32_t SPVM__Sys__User__endpwent(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "Sys::User#endpwent method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
+  
   endpwent();
   
   return 0;
@@ -186,6 +197,7 @@ int32_t SPVM__Sys__User__getpwent(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
   
   errno = 0;
+  
   struct passwd* pwent = getpwent();
   
   if (errno != 0) {
@@ -212,6 +224,7 @@ int32_t SPVM__Sys__User__setgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "Sys::User#setgrent method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
+  
   setgrent();
   
   return 0;
@@ -224,6 +237,7 @@ int32_t SPVM__Sys__User__endgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   env->die(env, stack, "Sys::User#endgrent method is not supported in this system(defined(_WIN32)).", __func__, FILE_NAME, __LINE__);
   return SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS;
 #else
+  
   endgrent();
   
   return 0;
@@ -239,6 +253,7 @@ int32_t SPVM__Sys__User__getgrent(SPVM_ENV* env, SPVM_VALUE* stack) {
   int32_t error_id = 0;
   
   errno = 0;
+  
   struct group* grent = getgrent();
   
   if (errno != 0) {
